/*
 * The MIT License
 *
 * Copyright (c) 2010, Dominik Bartholdi
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.jvnet.hudson.plugins.scriptler.config;

import org.kohsuke.stapler.DataBoundConstructor;

public class Script implements Comparable<Script>, NamedResource {

	public final String name;
	public final String comment;
	public final boolean available;
	public final String originCatalog;
	public final String originScript;
	public final String originDate;

	/**
	 * script is only transient, because it will not be saved in the xml but on
	 * the file system. Therefore it has to be materialized before usage!
	 */
	public transient String script;

	@DataBoundConstructor
	public Script(String name, String comment) {
		this.name = name;
		this.comment = comment;
		this.available = true;
		this.originCatalog = null;
		this.originScript = null;
		this.originDate = null;
	}

	public Script(String name, String comment, boolean available) {
		this.name = name;
		this.comment = comment;
		this.available = available;
		this.originCatalog = null;
		this.originScript = null;
		this.originDate = null;
	}

	/**
	 * Constructor to create a script imported from a foreign catalog.
	 * 
	 * @param name
	 * @param comment
	 * @param available
	 * @param originCatalog
	 * @param originScript
	 * @param originDate
	 */
	public Script(String name, String comment, boolean available, String originCatalog, String originScript, String originDate) {
		this.name = name;
		this.comment = comment;
		this.available = available;
		this.originCatalog = originCatalog;
		this.originScript = originScript;
		this.originDate = originDate;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jvnet.hudson.plugins.scriptler.config.NamedResource#getName()
	 */
	public String getName() {
		return name;
	}

	public void setScript(String script) {
		this.script = script;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Comparable#compareTo(java.lang.Object)
	 */
	public int compareTo(Script o) {
		return name.compareTo(o.name);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((name == null) ? 0 : name.hashCode());
		return result;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (!(obj instanceof Script)) {
			return false;
		}
		Script other = (Script) obj;
		if (name == null) {
			if (other.name != null) {
				return false;
			}
		} else if (!name.equals(other.name)) {
			return false;
		}
		return true;
	}

}
